tdub.config
--------------

.. currentmodule:: tdub.config

.. automodule:: tdub.config

Summary
^^^^^^^

.. autosummary::

   AVOID_IN_CLF
   AVOID_IN_CLF_1j1b
   AVOID_IN_CLF_2j1b
   AVOID_IN_CLF_2j2b
   FEATURESET_1j1b
   FEATURESET_2j1b
   FEATURESET_2j2b
   SELECTION_1j1b
   SELECTION_2j1b
   SELECTION_2j2b

Reference
^^^^^^^^^

.. autodata:: AVOID_IN_CLF
   :annotation:
.. autodata:: AVOID_IN_CLF_1j1b
   :annotation:
.. autodata:: AVOID_IN_CLF_2j1b
   :annotation:
.. autodata:: AVOID_IN_CLF_2j2b
   :annotation:
.. autodata:: FEATURESET_1j1b
   :annotation:
.. autodata:: FEATURESET_2j1b
   :annotation:
.. autodata:: FEATURESET_2j2b
   :annotation:
.. autodata:: SELECTION_1j1b
   :annotation:
.. autodata:: SELECTION_2j1b
   :annotation:
.. autodata:: SELECTION_2j2b
   :annotation:
